Module emoji

Module emoji 

Emoji support (Rich-style :name: codes).

Python Rich supports :emoji_name: inline codes with optional variants: :smile-text: and :smile-emoji:. When enabled on the Console, these codes are replaced with the corresponding unicode emoji + (optional) variant selector.

Enums

EmojiVariant
Emoji presentation variant selector.

Functions

get
Look up an emoji by its Rich shortcode name (case-sensitive).
replace
Replace Rich-style emoji codes in text.