pub fn render_or_plain(markup: &str) -> Text
Render markup to Text, returning plain text on error.
This is a convenience function that never fails - on parse error, it returns the original markup as plain text.