Constrain

Struct Constrain 

pub struct Constrain { /* private fields */ }
Constrain the width of a renderable to a given number of characters.

Implementations

Source

impl Constrain

pub fn new(renderable: impl Renderable + 'static, width: Option<usize>) -> Self

Create a Constrain wrapper around any renderable.

If width is None, this is a pass-through wrapper (matches Python Rich behavior).

pub fn new_boxed(renderable: Box<dyn Renderable>, width: Option<usize>) -> Self

Create a Constrain wrapper around a boxed renderable.

pub fn new_measurable( renderable: impl Renderable + RichMeasure + 'static, width: Option<usize>, ) -> Self

Create a Constrain wrapper around a renderable that supports measurement.

pub const fn width(self, width: Option<usize>) -> Self

Set / clear the constrain width.