pub struct Constrain { /* private fields */ }Expand description
Constrain the width of a renderable to a given number of characters.
Implementations
Sourceimpl Constrain
impl Constrain
Sourcepub fn new(renderable: impl Renderable + 'static, width: Option<usize>) -> Self
pub fn new(renderable: impl Renderable + 'static, width: Option<usize>) -> Self
Create a Constrain wrapper around any renderable.
If width is None, this is a pass-through wrapper (matches Python Rich behavior).
Sourcepub fn new_boxed(renderable: Box<dyn Renderable>, width: Option<usize>) -> Self
pub fn new_boxed(renderable: Box<dyn Renderable>, width: Option<usize>) -> Self
Create a Constrain wrapper around a boxed renderable.
Sourcepub fn new_measurable(
renderable: impl Renderable + RichMeasure + 'static,
width: Option<usize>,
) -> Self
pub fn new_measurable( renderable: impl Renderable + RichMeasure + 'static, width: Option<usize>, ) -> Self
Create a Constrain wrapper around a renderable that supports measurement.