pub struct Group<'a> { /* private fields */ }Expand description
A container that groups multiple renderables together.
Group implements the Renderable trait, allowing you to combine multiple renderables into a single unit. Each child is rendered in sequence with optional separators.
Implementations
Sourceimpl<'a> Group<'a>
impl<'a> Group<'a>
Sourcepub fn push<R: Renderable + 'a>(self, renderable: R) -> Self
pub fn push<R: Renderable + 'a>(self, renderable: R) -> Self
Add a renderable to the group.
The renderable is boxed and stored. You can add any type that implements the Renderable trait.
Sourcepub fn push_boxed(self, renderable: Box<dyn Renderable + 'a>) -> Self
pub fn push_boxed(self, renderable: Box<dyn Renderable + 'a>) -> Self
Add a boxed renderable to the group.